@@ -65,7 +65,7 @@ def mktorrent_win(filepath,torrentname,tracker="https://announce.leaguehd.com/an
         new_filepath=os.path.join(os.path.dirname(filepath),'AAABBBCCC')
         os.rename(filepath,new_filepath)
         logger.info('正在制作种子:'+filepath)
-        order='mktorrent -v -p -l 24 -c "Made by Auto_Upload" -a '+tracker+' -o \"'+changename(torrentname)+ '\" \"'+os.path.basename(new_filepath)+'\"'+''
+        order='mktorrent -v -p -f -l 24 -c "Made by Auto_Upload" -a '+tracker+' -o \"'+changename(torrentname)+ '\" \"'+os.path.basename(new_filepath)+'\"'+''
         #logger.info(order)
         
         trytime=0
@@ -88,7 +88,7 @@ def mktorrent_win(filepath,torrentname,tracker="https://announce.leaguehd.com/an
         new_filepath=os.path.join(os.path.dirname(filepath),'AAABBBCCC'+os.path.splitext(filepath)[-1])
         os.rename(filepath,new_filepath)
         logger.info('正在制作种子:'+filepath)
-        order='mktorrent -v -p -l 24 -c "Made by Auto_Upload" -a '+tracker+' -o \"'+changename(torrentname)+ '\" \"'+os.path.basename(new_filepath)+'\"'+''
+        order='mktorrent -v -p -f -l 24 -c "Made by Auto_Upload" -a '+tracker+' -o \"'+changename(torrentname)+ '\" \"'+os.path.basename(new_filepath)+'\"'+''
         #logger.info(order)
 
         trytime=0
